@@ -6,7 +6,7 @@ from datetime import datetime
 from atlassian import Bitbucket
 from atlassian.bitbucket import Cloud
 from atlassian.bitbucket.cloud.common.users import User
-from atlassian.bitbucket.cloud.repositories.pullRequests import Participant, PullRequest, Build
+from atlassian.bitbucket.cloud.repositories.pullRequests import Comment, Participant, PullRequest, Build
 
 BITBUCKET = None
 try:
@@ -45,6 +45,14 @@ class TestBasic:
             "testrepository1xxx"
         ), "Not exists repository"
 
+    def test_create_repositories(self):
+        result = CLOUD.workspaces.get("TestWorkspace1").repositories.create("TestRepositoryCreated")
+        assert result.description == "Test newly created repository", "Result of repositories [create(...)]"
+        result = CLOUD.workspaces.get("TestWorkspace1").repositories.create("TestRepositoryCreated", "TEST1")
+        assert (
+            result.description == "Test newly created repository in project TEST1"
+        ), "Result of repositories [create(...)] with project"
+
     def test_get_repositories(self):
         result = [x["name"] for x in BITBUCKET.get_repositories("TestWorkspace1")]
         assert result == ["testrepository1", "testrepository2"], "Result of [get_repositories(...)]"
@@ -143,11 +151,11 @@ class TestBasic:
     def test_is_default_reviewer(self):
         result = BITBUCKET.is_default_reviewer("TestWorkspace1", "testrepository1", "DefaultReviewerNo")
         assert result is False, "Result of [is_default_reviewer(...)]"
-        result = BITBUCKET.is_default_reviewer("TestWorkspace1", "testrepository1", "DefaultReviewer1")
+        result = BITBUCKET.is_default_reviewer("TestWorkspace1", "testrepository1", "DefaultReviewer1Uuid")
         assert result is True, "Result of [is_default_reviewer(...)]"
 
     def test_delete_default_reviewer(self):
-        result = BITBUCKET.delete_default_reviewer("TestWorkspace1", "testrepository1", "DefaultReviewer1")[
+        result = BITBUCKET.delete_default_reviewer("TestWorkspace1", "testrepository1", "DefaultReviewer1Uuid")[
             "account_id"
         ]
         assert result == "DefaultReviewer1AccountId", "Result of [delete_default_reviewer(...)]"
@@ -257,6 +265,17 @@ class TestPullRequests:
         assert com["pullrequest"]["id"] == 1
         assert not com["deleted"]
 
+    def test_comments(self, tc1):
+        comments = list(tc1.comments())
+        assert len(comments) == 2
+        c1, c2 = comments
+        assert isinstance(c1, Comment)
+        assert isinstance(c2, Comment)
+        assert c1.raw == "Test comment 1"
+        assert isinstance(c1.user, User)
+        assert c1.user.display_name == "User04DisplayName"
+        assert c2.html == "<p>Test comment 2</p>"
+
     def test_approve(self, tc1):
         ap = tc1.approve()
         assert ap["approved"]
